@@ -1,18 +1,19 @@
 cat2pal <- function(x, 
 					palette = "Set3",
+					auto.palette.mapping = TRUE,
 					contrast = 1, 
 					colorNA = "#FF1414",
 					legend.labels = NULL,
 					max_levels = 40,
 					legend.NA.text = "Missing",
+					showNA = NA,
 					process.colors) {
-	if (!is.factor(x)) x <- factor(x, levels=sort(unique(x)))
-	
+  if (!is.factor(x)) x <- factor(x, levels=sort(unique(x)))
 	
 	
 	# quick&dirty
 	nCol <- nlevels(x)
-	if (nCol > max_levels) {
+	if (nCol > max_levels && !auto.palette.mapping) {
 
 		mapping <- as.numeric(cut(seq.int(nCol), breaks=max_levels))
 		to <- c(which(mapping[-nCol] - mapping[-1]!=0), nCol)
@@ -23,6 +24,7 @@ cat2pal <- function(x,
 		
 		x <- factor(mapping[as.integer(x)], levels=1:max_levels, labels=new_lvls)
 	}
+	nCol <- nlevels(x)
 	
 	# reverse palette
 	if (length(palette)==1 && substr(palette[1], 1, 1)=="-") {
@@ -31,22 +33,12 @@ cat2pal <- function(x,
 	} else revPal <- function(p)p
 	
 
-	n <- nlevels(x)
 	legend.palette <- if (palette[1] %in% rownames(brewer.pal.info)) {
-		brewerpal <- brewer.pal(min(brewer.pal.info[palette, "maxcolors"], max(n, 3)), name=palette)
-		if (brewer.pal.info[palette, "category"]=="qual") {
-			p <- rep(brewerpal, length.out=nlevels(x))
-		} else {
-			if (length(contrast)==1) contrast <- c(0, contrast)
-			crange <- contrast[2] - contrast[1]
-			ext <- nlevels(x)/crange
-			from <- floor(contrast[1] * ext)
-			to <- from + nlevels(x)
-			p <- colorRampPalette(brewerpal)(ext)[from:to]
-		}
-		revPal(p)
+		revPal(get_brewer_pal(palette, nCol, contrast, stretch = auto.palette.mapping))
 	} else {
-        rep(palette, length.out=nlevels(x))
+		if (auto.palette.mapping) {
+			colorRampPalette(palette)(nCol)
+		} else rep(palette, length.out=nCol)
 	}
     
 # 	if (!is.null(process.colors)) {
@@ -63,14 +55,19 @@ cat2pal <- function(x,
 	if (is.null(legend.labels)) {
 		legend.labels <- levels(x)	
 	} else {
-		legend.labels <- rep(legend.labels, length.out = n)
+		legend.labels <- rep(legend.labels, length.out = nCol)
 	}
 	if (any(colsNA)) {
-		cols[is.na(cols)] <- colorNA
-		if (!is.na(legend.NA.text)) {
-			legend.labels <- c(legend.labels, legend.NA.text)
-			legend.palette <- c(legend.palette, colorNA)
-		}
+		if (is.na(showNA)) showNA <- TRUE
+		cols[colsNA] <- colorNA
+	} else {
+		if (is.na(showNA)) showNA <- FALSE
+	}
+
+	
+	if (showNA) {
+		legend.labels <- c(legend.labels, legend.NA.text)
+		legend.palette <- c(legend.palette, colorNA)
 	}
 	
 	list(cols=cols, legend.labels=legend.labels, legend.palette=legend.palette)
