@@ -7,5 +7,5 @@ is_projected <- function(x) {
 }
 
 maybe_longlat <- function(bb) {
-	(bb[1,1] >= -365 && bb[1,2] <= 365 && bb[2,1] >= -90.1 && bb[2,2] <= 90.1)
+	(bb[1,1] >= -180.1 && bb[1,2] <= 180.1 && bb[2,1] >= -90.1 && bb[2,2] <= 90.1)
 }
\ No newline at end of file
