@@ -98,7 +98,7 @@ plot_all <- function(i, gp, shps, dasp, sasp, inner.margins.new, legend_pos, use
 	leg <- legend_prepare(gp, gt, lineInch)
 	
 	## legend, title, and other thinks such as compass
-	if (!is.null(leg) || gt$title!="" || gt$credits.show || gt$scale.show || gt$compass.show) {
+	if (!is.null(leg) || nonempty_text(gt$title) || gt$credits.show || gt$scale.show || gt$compass.show) {
 		if (!is.na(gt$frame)) {
 			pH <- convertHeight(unit(1, "points"), unitTo = "npc", valueOnly = TRUE)*gt$frame.lwd
 			pW <- convertWidth(unit(1, "points"), unitTo = "npc", valueOnly = TRUE)*gt$frame.lwd
