@@ -28,7 +28,7 @@
 #' 
 #' @name tm_layout
 #' @rdname tm_layout
-#' @param title Title(s). By default, the name of the statistical variable of which the legend is drawn at the top (see \code{legend.config}) is used as a title.
+#' @param title Global title of the map. For small multiples, multiple titles can be specified. Titles for the legend items are specified at the layer functions (e.g. \code{\link{tm_fill}}). 
 #' @param scale numeric value that serves as the global scale parameter. All font sizes, bubble sizes, border widths, and line widths are controled by this value. Each of these elements can be scaled independantly with the \code{scale}, \code{lwd}, or \code{size} arguments provided by the \code{\link{tmap-element}s}.
 #' @param title.size Relative size of the title
 #' @param bg.color Background color. By default it is \code{"white"}. A recommended alternative for choropleths is light grey (e.g., \code{"grey85"}).
@@ -56,9 +56,10 @@
 #' @param legend.show Logical that determines whether the legend is shown.
 #' @param legend.only logical. Only draw the legend (without map)? Particularly useful for small multiples with a common legend.
 #' @param legend.outside Logical that determines whether the legend is plot outside of the map/facets. Especially useful when using facets that have a common legend (i.e. with \code{free.scales=FALSE}).
-#' @param legend.outside.position Character vector of two values that determine the outside position of the legend. Only applicable when \code{legend.outside=TRUE}. The first value determines the side of the map/facets, one of: \code{"right"}, \code{"left"}, \code{"top"}, or \code{"bottom"}. The second value determines the alignment of the legend, one of \code{"top"}, \code{"center"}, or \code{"bottom"} when the first value is \code{"left"} or \code{"right"}; one of \code{"left"}, \code{"center"}, \code{"right"} when the first value is \code{"top"} or \code{"bottom"}.
+#' @param legend.outside.position Character that determines the outside position of the legend. Only applicable when \code{legend.outside=TRUE}. One of: \code{"right"}, \code{"left"}, \code{"top"}, or \code{"bottom"}.
 #' @param legend.outside.size Numeric value that determines the relative size of the legend, when \code{legend.outside=TRUE}. If the first value of \code{legend.outside.position} is \code{"top"} or \code{"bottom"}, then it is the width of the legend, else it is the height of the legend.
-#' @param legend.position Position of the legend. Vector of two values, specifing the x and y coordinates. Either this vector contains "left", "LEFT", "center", "right", or "RIGHT" for the first value and "top", "TOP", "center", "bottom", or "BOTTOM" for the second value, or this vector contains two numeric values between 0 and 1 that specifies the x and y coordinates of the left bottom corner of the legend. The uppercase values correspond to the position without margins (so tighter to the frame). By default, it is automatically placed in the corner with most space based on the (first) shape object.
+#' @param legend.position Position of the legend. Vector of two values, specifing the x and y coordinates. Either this vector contains \code{"left"}, \code{"LEFT"}, \code{"center"}, \code{"right"}, or \code{"RIGHT"} for the first value and \code{"top"}, \code{"TOP"}, \code{"center"}, \code{"bottom"}, or \code{"BOTTOM"} for the second value, or this vector contains two numeric values between 0 and 1 that specifies the x and y coordinates of the left bottom corner of the legend. The uppercase values correspond to the position without margins (so tighter to the frame). By default, it is automatically placed in the corner with most space based on the (first) shape object. If \code{legend.outside=TRUE}, this argument specifies the legend position within the outside panel.
+#' @param legend.just Justification of the legend relative to the point coordinates.  The first value specifies horizontal and the second value vertical justification. Possible values are: \code{"left"} , \code{"right"}, \code{"center"}, \code{"bottom"}, and \code{"top"}. Numeric values of 0 specify left/bottom alignment and 1 right/top alignment. This option is only used, if legend.position is specified by numeric coordinates.
 #' @param legend.width maximum width of the legend
 #' @param legend.height maximum height of the legend.
 #' @param legend.hist.height height of the histogram. This hight is initial. If the total legend is downscaled to \code{legend.height}, the histogram is downscaled as well.
@@ -81,20 +82,25 @@
 #' @param legend.bg.alpha Transparency number between 0 (totally transparent) and 1 (not transparent). By default, the alpha value of the \code{legend.bg.color} is used (normally 1).
 #' @param legend.hist.bg.color Background color of the histogram
 #' @param legend.hist.bg.alpha Transparency number between 0 (totally transparent) and 1 (not transparent). By default, the alpha value of the \code{legend.hist.bg.color} is used (normally 1).
-#' @param title.snap.to.legend Logical that determines whether the title is part of the legend.
+#' @param title.snap.to.legend Logical that determines whether the title is part of the legend. By default false, unless \code{legend.outside} is \code{TRUE}
 #' @param title.position Position of the title. Vector of two values, specifing the x and y coordinates. Either this vector contains "left", "LEFT", "center", "right", or "RIGHT" for the first value and "top", "TOP", "center", "bottom", or "BOTTOM" for the second value, or this vector contains two numeric values between 0 and 1 that specifies the x and y coordinates of the tile. The uppercase values correspond to the position without margins (so tighter to the frame). 
 #' By default the title is placed on top of the legend (determined by \code{legend.position}).
 #' @param title.color color of the title
 #' @param legend.frame either a logical that determines whether the legend is placed inside a frame, or a color that directly specifies the frame border color. The width of the frame is automatically determined, but is upper-bounded by \code{legend.width}.
-#' @param title.bg.color background color of the title. Use \code{TRUE} to match with the overall background color \code{bg.color}.
+#' @param title.bg.color background color of the title. Use \code{TRUE} to match with the overall background color \code{bg.color}. By default, it is \code{TRUE} if \code{legend.frame} is \code{TRUE} or a color.
 #' @param title.bg.alpha Transparency number between 0 (totally transparent) and 1 (not transparent). By default, the alpha value of the \code{title.bg.color} is used (normally 1).
 #' @param panel.show Logical that determines if the map(s) are shown as panels. If \code{TRUE}, the title will be placed in the panel header instead of inside the map. By default, it is \code{TRUE} when small multiples are created with the \code{by} variable. (See \code{\link{tm_facets}}) 
+#' @param panel.labels Panel labels. Only applicable when \code{panel.show} is \code{TRUE}. For cross tables facets, it should be a list containing the row names in the first, and column names in the second item.
 #' @param panel.label.size Relative font size of the panel labels
 #' @param panel.label.color Font color of the panel labels
 #' @param panel.label.bg.color Background color of the panel labels
 #' @param panel.label.height Height of the labels in number of text line heights.
 #' @param panel.label.rot Rotation angles of the panel labels. Vector of two values: the first is the rotation angle (in degrees) of the row panels, which are only used in cross-table facets (when \code{\link{tm_facets}}'s \code{by} is specified with two variables). The second is the rotation angle of the column panels.
-#' @param attr.position Position of the map attributes, which are \code{\link{tm_credits}}, \code{\link{tm_scale_bar}} and \code{\link{tm_compass}}. Vector of two values, specifing the x and y coordinates. The first value is "left", "LEFT", "center", "right", or "RIGHT", and the second value "top", "TOP", "center", "bottom", or "BOTTOM". The uppercase values correspond to the position without margins (so tighter to the frame). Positions can also be set separately in the map attribute fuctions.
+#' @param attr.outside Logical that determines whether the attributes are plot outside of the map/facets.
+#' @param attr.outside.position Character that determines the outside position of the legend, either \code{top} or \code{bottom}. Only applicable when \code{attr.outside=TRUE}.
+#' @param attr.outside.size Numeric value that determines the relative height of the attribute viewport, when \code{attr.outside=TRUE}.
+#' @param attr.position Position of the map attributes, which are \code{\link{tm_credits}}, \code{\link{tm_scale_bar}} and \code{\link{tm_compass}}. Vector of two values, specifing the x and y coordinates. The first value is \code{"left"}, \code{"LEFT"}, \code{"center"}, \code{"right"}, or \code{"RIGHT"}, and the second value \code{"top"}, \code{"TOP"}, \code{"center"}, \code{"bottom"}, or \code{"BOTTOM"}. The uppercase values correspond to the position without margins (so tighter to the frame). Positions can also be set separately in the map attribute fuctions. If \code{attr.outside=TRUE}, this argument specifies the position of the attributes within the outside panel.
+#' @param attr.just Justification of the attributes relative to the point coordinates.  The first value specifies horizontal and the second value vertical justification. Possible values are: \code{"left"} , \code{"right"}, \code{"center"}, \code{"bottom"}, and \code{"top"}. Numeric values of 0 specify left/bottom alignment and 1 right/top alignment. This option is only used, if legend.position is specified by numeric coordinates.
 #' @param design.mode Logical that enables the design mode. If \code{TRUE}, inner and outer margins, legend position, aspect ratio are explicitely shown. Also, feedback text in the console is given.
 #' @param basemaps vector of one or more names of baselayer maps used in the interactive view mode. See \code{\link{tm_view}}.
 #' @param bg.overlay color of the background overlay rectangle used in the interactive view mode. See \code{\link{tm_view}}.
@@ -107,7 +113,7 @@ tm_layout <- function(title=NA,
 					  scale=1,
 					  title.size=1.3,
 					  bg.color= "white",
-					  aes.color=c(fill="grey85", borders="grey40", bubbles="blueviolet", dots="black", lines="red", text="black", na="grey70"),
+					  aes.color=c(fill="grey85", borders="grey40", bubbles="blueviolet", dots="black", lines="red", text="black", na="grey75"),
 					  aes.palette=list(seq="YlOrBr", div="RdYlGn", cat="Set3"),
 					  attr.color="black",
   					  sepia.intensity=0, 
@@ -134,6 +140,7 @@ tm_layout <- function(title=NA,
 					  legend.outside.position="right",
 					  legend.outside.size=0.3,
 					  legend.position = NULL,
+					  legend.just = c("left", "bottom"),
 					  legend.width = 0.4,
 					  legend.height = 0.9,
 					  legend.hist.height = 0.3,
@@ -150,18 +157,23 @@ tm_layout <- function(title=NA,
 					  legend.bg.alpha = 1,
 					  legend.hist.bg.color = NA,
 					  legend.hist.bg.alpha = 1,
-					  title.snap.to.legend = FALSE,
+					  title.snap.to.legend = NA,
 					  title.position = c("left", "top"),
 					  title.color=attr.color,
 					  title.bg.color=NA,
 					  title.bg.alpha = 1,
 					  panel.show = NA,
+					  panel.labels=NA,
 					  panel.label.size = 1,
 					  panel.label.color = "black",
 					  panel.label.bg.color = "grey80",
 					  panel.label.height = 1.25,
 					  panel.label.rot = c(90, 0),
+					  attr.outside = FALSE,
+					  attr.outside.position = "bottom",
+					  attr.outside.size=NA,
 					  attr.position = c("right", "bottom"),
+					  attr.just = c("left", "bottom"),
 					  design.mode = FALSE,
 					  basemaps = c("CartoDB.Positron", "OpenStreetMap", "Esri.WorldTopoMap"),
 					  bg.overlay=NULL,
@@ -214,20 +226,39 @@ tm_format_World_wide <- function(title=NA,
 #' @export
 tm_format_Europe <- function(title=NA,
 							 title.position=c("left", "top"),
-							 legend.position=c("left", "top"), 
-							 attr.position=c("left", "bottom"),
-							 inner.margins=c(0, 0.1, 0, 0),
+							 legend.position=c("right", "top"),
+							 legend.just=c("right", "top"),
+							 attr.position=c("right", "bottom"),
+							 legend.frame=TRUE,
+							 inner.margins=c(0, 0, 0, 0),
 							 
 							 ...) {
 	args <- c(as.list(environment()), list(...))
 	do.call("tm_layout", args)
 }
 
+#' @rdname tm_layout
+#' @export
+tm_format_Europe2 <- function(title=NA,
+							  title.position=c("left", "top"),
+							  legend.position=c("left", "top"),
+							  legend.outside=TRUE,
+							  legend.outside.size=.2,
+							  legend.just=c("right", "top"),
+							  attr.position=c("right", "bottom"),
+							  inner.margins=c(0, 0, 0, 0),
+							  ...) {
+	args <- c(as.list(environment()), list(...))
+	do.call("tm_layout", args)
+}
+
 #' @rdname tm_layout
 #' @export
 tm_format_Europe_wide <- function(title=NA,
-								  title.position=c("left", "top"),
-							 legend.position=c("left", "top"), 
+								  title.position=c("left",.85),
+								  title.snap.to.legend=TRUE,
+							 legend.position=c("left", .85), 
+							 legend.just=c("left", "top"),
 							 attr.position=c("left", "bottom"),
 							 inner.margins=c(0, 0.25, 0, 0),
 							 ...) {
@@ -290,6 +321,8 @@ tm_style_natural <- function(bg.color="lightskyblue1",
 							 aes.palette=list(seq="YlGn", div="RdYlGn", cat="Set3"),
 							 attr.color="black", 
 							 space.color="white",
+							 legend.frame=TRUE,
+							 legend.bg.color="grey90",
 							 earth.boundary=TRUE,
 							 basemaps="MapQuestOpen.OSM",
 							 ...) {
